==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode.md <==
# AmazonRedshiftDenseComputeNode


```text
aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode
```

```text
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')
```



| Illustration | AmazonRedshiftDenseComputeNode | AmazonRedshiftDenseComputeNodeCard | AmazonRedshiftDenseComputeNodeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode.png) | ![illustration for AmazonRedshiftDenseComputeNode](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode.Local.png) | ![illustration for AmazonRedshiftDenseComputeNodeCard](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNodeCard.Local.png) | ![illustration for AmazonRedshiftDenseComputeNodeGroup](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNodeGroup.Local.png) |




## AmazonRedshiftDenseComputeNode

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNode
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNode('AmazonRedshiftDenseComputeNode', 'Amazon Redshift Dense Compute Node', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNode
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNode('AmazonRedshiftDenseComputeNode', 'Amazon Redshift Dense Compute Node', 'an optional tech label')
@enduml
```

## AmazonRedshiftDenseComputeNodeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeCard
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeCard('AmazonRedshiftDenseComputeNodeCard', 'Amazon Redshift Dense Compute Node Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeCard
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeCard('AmazonRedshiftDenseComputeNodeCard', 'Amazon Redshift Dense Compute Node Card', 'an optional description')
@enduml
```

## AmazonRedshiftDenseComputeNodeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeGroup
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeGroup('AmazonRedshiftDenseComputeNodeGroup', 'Amazon Redshift Dense Compute Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeGroup
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeGroup('AmazonRedshiftDenseComputeNodeGroup', 'Amazon Redshift Dense Compute Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode.md <==
# AmazonRedshiftDenseComputeNode


```text
aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode
```

```text
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')
```



| Illustration | AmazonRedshiftDenseComputeNode | AmazonRedshiftDenseComputeNodeCard | AmazonRedshiftDenseComputeNodeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode.png) | ![illustration for AmazonRedshiftDenseComputeNode](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode.Local.png) | ![illustration for AmazonRedshiftDenseComputeNodeCard](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNodeCard.Local.png) | ![illustration for AmazonRedshiftDenseComputeNodeGroup](../../../aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNodeGroup.Local.png) |




## AmazonRedshiftDenseComputeNode

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNode
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNode('AmazonRedshiftDenseComputeNode', 'Amazon Redshift Dense Compute Node', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNode
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNode('AmazonRedshiftDenseComputeNode', 'Amazon Redshift Dense Compute Node', 'an optional tech label')
@enduml
```

## AmazonRedshiftDenseComputeNodeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeCard
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeCard('AmazonRedshiftDenseComputeNodeCard', 'Amazon Redshift Dense Compute Node Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeCard
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeCard('AmazonRedshiftDenseComputeNodeCard', 'Amazon Redshift Dense Compute Node Card', 'an optional description')
@enduml
```

## AmazonRedshiftDenseComputeNodeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeGroup
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeGroup('AmazonRedshiftDenseComputeNodeGroup', 'Amazon Redshift Dense Compute Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRedshiftDenseComputeNodeGroup
include('aws-q3-2021/Resource/Analytics/AmazonRedshiftDenseComputeNode')

' renders the element
AmazonRedshiftDenseComputeNodeGroup('AmazonRedshiftDenseComputeNodeGroup', 'Amazon Redshift Dense Compute Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
